@@ -1,4 +1,5 @@
-__version__ = '0.3.8'
+#coding = utf-8
+__version__ = '0.3.9'
 
 import random
 from termcolor import colored, cprint
@@ -8,13 +9,20 @@ from art import *
 import os
 import json
 import requests
-import urllib3
+import getpass
+import uuid
 pathToScript = os.path.dirname(os.path.abspath(__file__))
+def pathToSave()->str:
+    if platform.system() == 'Windows':
+        path = str(r"c:\Users\{}\PetchouApps".format(getpass.getuser()))
+        return path
+    else:
+        return f"/Users/{getpass.getuser()}/PetchouApps"
 
 
 
 
-from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner
+from datas import variables, loading, setGrid, getPlayers, notDone, isWinner, setIcon
 vars = variables()
 colors = vars.colors
 cases = vars.scheme
@@ -118,7 +126,7 @@ def game(joueurs, gameManager):
 
     time.sleep(2)
     os.system(commands[sys][0])
-    tprint('Game over')
+    
     """print(p)
     print(type(p))
     print(p1)
@@ -127,16 +135,38 @@ def game(joueurs, gameManager):
     print(type(p2))
     print(gameManager)"""
 
-    p1stats = gameManager[str(p1)]
     
-    p2stats = gameManager[str(p2)]
     
     if isWinner() == False:
         trun = 9
     else: 
         turn = 11
+    EndScreen(turn, gameManager, p1, p2, p)
+
+    
 
 
+def eraseDatas(turn, gameManager, p1, p2, p):
+    print('recopier les caractères ci-dessous pour confirmer :')
+    captcha = str(uuid.uuid4())
+    captcha = captcha[:5]
+    a = input('')
+    if a == captcha:
+        gameManager = {"# Error 509 TroubleShooter" : "debug"}
+        with open(f'{pathToSave()}/save.json', 'w', encoding='utf-8') as file:
+            json.dump(gameManager, file)
+            print('Données éffacées ! Le jeu se ferme...')
+            time.sleep(1)
+            os.system(commands[sys][2])
+    else: 
+        print('Erreur de vérification, réessayez.')
+        EndScreen(turn, gameManager, p1, p2)
+
+def EndScreen(turn, gameManager, p1, p2, p):
+    p1stats = gameManager[str(p1)]
+    
+    p2stats = gameManager[str(p2)]
+    tprint('Game over')
     if turn == 11:
         p1stats[2] = p1stats[2] + 1
         p2stats[2] = p2stats[2] + 1
@@ -153,7 +183,7 @@ def game(joueurs, gameManager):
     gameManager[p1] = p1stats
     gameManager[p2] = p2stats
 
-    with open('save.json', 'w', encoding='utf-8') as file:
+    with open(f'{pathToSave()}/save.json', 'w', encoding='utf-8') as file:
         json.dump(gameManager, file)
 
     print(colored(f"\nSTATS :\n", 'red'))   
@@ -162,10 +192,12 @@ def game(joueurs, gameManager):
     print("\nVoulez vous rejouer ?")
     print("1) Quitter le jeu")
     print("2) Rejouer")
-    print("3) Changer de joueurs")  
+    print("3) Changer de joueurs") 
+    print("4) Paramètres") 
+
     def endGameChoice() -> str:
         choice = input("")
-        if choice == "1" or choice == "2" or choice == "3":
+        if choice == "1" or choice == "2" or choice == "3" or choice == "4":
             return choice
         else:
             return endGameChoice()
@@ -178,19 +210,39 @@ def game(joueurs, gameManager):
     elif mode ==3 :
         os.system(commands[sys][0])
         players = []
-        temp = getPlayers()
+        temp = getPlayers(pathToSave())
         for p in temp.keys():
             players.append(p)
         setGame(players, gameManager)
+    
+    elif mode == 4:
+        os.system(commands[sys][0])
+        tprint('Settings')
+        print("\nQue voulez-vous faire ?")
+        print("1) Effacer les sauvegardes")
+        print("2) Créer l'icone de bureau")
+        print("3) Changer de Langue - pas encore disponible") 
+        print("4) Retour") 
 
-
-
+        def endGameChoice() -> str:
+            choice = input("")
+            if choice == "1" or choice == "2" or choice == "3" or choice == "4":
+                return choice
+            else:
+                return endGameChoice()
+        mode = int(endGameChoice())
+        if mode == 1:
+            eraseDatas(turn, gameManager, p1, p2, p)
+        if mode == 2:
+            setIcon(platform.system(), pathToScript)
 
 if __name__ == "__main__":
-    loading()
+    os.chdir(pathToScript)
+    loading(__version__, pathToScript, pathToSave())
     os.system(commands[sys][0])
     #pathToScript = os.path.dirname(os.path.abspath(__file__))
     #print(pathToScript)
-    gameManager = getPlayers(pathToScript)
+    gameManager = getPlayers(pathToSave())
+    os.chdir(pathToScript)
     setGame(joueurs, gameManager)
     
