@@ -6,7 +6,8 @@ import json
 import platform
 import requests
 import urllib3
-
+import getpass
+import pkg_resources
 def internet_on() ->bool:
     url = "http://www.google.com"
     timeout = 5
@@ -16,12 +17,28 @@ def internet_on() ->bool:
     except (requests.ConnectionError, requests.Timeout) as exception:
         return False
 
+def isfirst(pathToSave)->bool:
+    try:
+        with open(pathToSave+"/save.json", "r"):
+            pass
+    except FileNotFoundError:
+        print('Initializing filesystem')
+        print(pathToSave)
+        a = input('...')
+        os.system(f'mkdir {pathToSave}')
+        os.system(f'/Users/{getpass.getuser()}/PetchouApps/save.json')
+        with open(f"/Users/{getpass.getuser()}/PetchouApps/save.json", "w") as troubleshot:
+            dict_init = {"#509 troubleshooting": "debug"}
+            json.dump(dict_init, troubleshot)
+            a = input()
+        
 
-commands = {"Windows": ["cls", "exit", "pip install --upgrade Morpion "], "Linux":["clear", """
+
+commands = {"Windows": ["cls", "exit", "pip install --upgrade Morpion ", "python -m Morpion"], "Linux":["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
-        """, "pip3 install --upgrade Morpion"], "Darwin": ["clear", """
+        """, "pip3 install --upgrade Morpion", "python3 -m Morpion"], "Darwin": ["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
-        """, "pip3 install --upgrade Morpion "] }
+        """, "pip3 install --upgrade Morpion ", "python3 -m Morpion"] }
 sys = platform.system()
 class variables():
     def __init__(self):
@@ -34,7 +51,16 @@ class variables():
 def loadFormat(x, base=2) -> int:
     return base * round(x/base)
 
-def loading():
+def loading(currentVersion, path, SavePath):
+    
+    if isfirst(SavePath):
+        print('Bienvenue, ceci est votre première session, voulez-vous créer une icon de bureau ? En cas de refus, cette action sera toujours disponible dans les paramètres de fin de partie.')
+        print('non -> tapez n')
+        print("oui -> tapez n'importe quelle touche")
+        a = input('')
+        if a != 'n':
+            setIcon(platform.system(), path)
+
     os.system(commands[sys][0])
     tprint("morpion")
     fill = colored('■', "blue")
@@ -63,7 +89,11 @@ def loading():
     print('Checking for updates...')
     if internet_on():
         os.system(commands[sys][2])
-    time.sleep(2)
+        v = pkg_resources.get_distribution("Morpion").version
+        if v != currentVersion:
+            os.system(f"{commands[sys][3]} ")
+
+    time.sleep(1)
     os.system(commands[sys][0])
 
 global cases
@@ -168,4 +198,21 @@ def isWinner() -> bool:
     else:
         return True
 
-    
\ No newline at end of file
+
+def setIcon(os, path):
+    if os == 'Windows':
+        try:
+            os.system('pip install winshell')
+            os.system('pip install pywin32')
+            os.system('pip install pypiwin32')
+            import winshell
+            desktop = winshell.desktop()
+            with winshell.shortcut(os.path.join(desktop, "Morpion.lnk")) as shortcut:
+                shortcut.path = f"{path}\morpion.bat"
+                shortcut.icon = f"{path}\morpionIcon.png"
+                shortcut.description = "PetchouApps' Morpion/TicTacToe game"
+        except os.error:
+            pass
+    else:
+        os.system(f'cp {path}/morpionUnix.sh /Users/{getpass.getuser()}/Desktop/Morpion.sh')
+        os.system('chmod 755 /Users/{getpass.getuser()}/Desktop/Morpion.sh')
\ No newline at end of file
